@@ -2,6 +2,7 @@
 import os
 import urllib2
 from xml.dom.minidom import parseString
+import webbrowser
 
 try:
     from PyQt4.QtGui import *
@@ -20,7 +21,7 @@ except:
 from appitem_ui import Ui_Form
 
 class AppItem(QWidget):
-    def __init__(self, parent=0, data={ 'name' : "", "karma" : 0, "pname" : "", "version" : "", "status" : "", "waiting" : "", "voted" : False, "myvote" : False }):
+    def __init__(self, parent=0, data={ 'name' : "", "karma" : 0, "pname" : "", "version" : "", "status" : "", "waiting" : "", "voted" : False, "myvote" : False, "bugtracker" : "" }):
         QWidget.__init__(self)
         self.ui = Ui_Form()
         self.ui.setupUi(self)
@@ -30,44 +31,67 @@ class AppItem(QWidget):
         self.version = data["version"]
         self.status = data["status"]
         self.waiting = data["waiting"]
+        self.age = QDateTime.fromString(self.waiting, "yyyy-MM-dd HH:mm UTC").daysTo(QDateTime.currentDateTime())
         self.voted = data["voted"]
         self.myvote = data["myvote"]
+        self.bugtracker = data["bugtracker"]
         self.id = ""
         
+        if not self.bugtracker:
+            self.ui.pButton_bug.setVisible(False)
+            
         self.configure()
         
-        self.connect(self.ui.pButton_install, SIGNAL("clicked()"), self.debInstall)
         self.connect(self.ui.pButton_pdetails, SIGNAL("clicked()"), self.debDetails)
+        self.connect(self.ui.pButton_bug, SIGNAL("clicked()"), self.bugReport)
         
-
     @pyqtSlot()
     def configure(self):
-        self.ui.pButton_vote.setText("%s, Karma %s, %s" % (self.version, self.karma, self.waiting))
-        if self.status: # unlocked
-            self.ui.pButton_vote.setIcon(QIcon())
-        elif self.karma >= 10: # this is not correct, but hey... it's easy to code
-            self.ui.pButton_vote.setIcon(QIcon(QPixmap(":/icons/clock.png")))
-            
-        self.ui.pname.setText(self.name)
-        myvote = ""
-        publicvote = ""
-        if self.voted:
-            # pButton_vote.setEnabled(False) # can't disable as then you couldn't change your vote
-            if self.myvote:
-                myvote = " border-style: outset; border-color: green; border-width: 2px;"
-            else:
-                myvote = " border-style: outset; border-color: red; border-width: 2px;"
-            
-        self.ui.pButton_vote.setStyleSheet("QPushButton{ %s %s}" % (myvote, publicvote))
-
-    @pyqtSlot()
-    def debInstall(self):
-        QMessageBox.information(self, "%s %s" % (self.name, self.version), "Insert install functionality here. I take patches.")
+#        self.ui.pButton_vote.setText("%s, Karma %s, %s days old" % (self.version, self.karma, self.age))
         
+        if self.name.length() > 40:
+            self.ui.pButton_vote.setText(self.name[0:40]+ "...")
+        else:
+            self.ui.pButton_vote.setText(self.name)
+            
+        self.ui.updateLabel.setVisible(False)
+        self.ui.unlockedLabel.setVisible(False)
+        self.ui.hasvotesLabel.setVisible(False)
+        self.ui.quarantineLabel.setVisible(False)
+        if self.status: # unlocked
+#            self.ui.pButton_vote.setIcon(QIcon())
+            self.ui.unlockedLabel.setVisible(True)
+            self.ui.scoreAgeLabel.setVisible(False)
+            self.ui.pButton_vote.setFlat(True)
+        else:
+            if self.karma >= 10:
+#            self.ui.pButton_vote.setIcon(QIcon(QPixmap(":/icons/clock.png")))
+                self.ui.hasvotesLabel.setVisible(True)
+            if self.age < 10:
+                self.ui.quarantineLabel.setVisible(True)
+                
+        if self.voted:
+            self.ui.pButton_vote.setFlat(True)
+            if self.myvote:
+                self.ui.pButton_vote.setIcon(QIcon(QPixmap(":/icons/favourite.png")))
+            else:
+                self.ui.pButton_vote.setIcon(QIcon(QPixmap(":/icons/buried.png")))
+            
+        self.ui.scoreAgeLabel.setText("%s/%s" % (self.karma, self.age))
+
     @pyqtSlot()
     def debDetails(self):
         QMessageBox.information(self, "%s %s" % (self.name, self.version), "Insert details functionality here (REST, or, probably better, from apt-cache show). I take patches.")
         
+    @pyqtSlot()
+    def bugReport(self):
+#        if self.bugtracker.startswith("mailto"):
+#            #send mail
+#            pass
+#        else:
+        if self.bugtracker:
+            webbrowser.open(self.bugtracker)
+    
     @pyqtSlot()
     def getId(self): # ugliest REST hack on the planet
         if self.id:
