@@ -51,6 +51,18 @@ class Vote(QMainWindow):
                      
         self.connect(self.ui.failButton, SIGNAL("clicked(bool)"), self.failVote)
         self.connect(self.ui.passButton, SIGNAL("clicked(bool)"), self.passVote)
+        self.connect(self.ui.commentButton, SIGNAL("clicked(bool)"), self.comment)
+        
+    def show(self):
+        self.ui.cBox_cpu.setChecked(False)
+        self.ui.cBox_brk.setChecked(False)
+        self.ui.cBox_bug.setChecked(False)
+        self.ui.cBox_dub.setChecked(False)
+        self.ui.cBox_lic.setChecked(False)
+        self.ui.cBox_opt.setChecked(False)
+        self.ui.cBox_pwr.setChecked(False)
+        self.ui.textEdit.setText("")
+        QMainWindow.show(self)
         
     @pyqtSlot()
     def unlockCheck(self):
@@ -68,6 +80,7 @@ class Vote(QMainWindow):
     @pyqtSlot()
     def passVote(self):
         if self.passUnlocked:
+            self.comment()
             self.thumb(True)
         else:
             QMessageBox.information(self, "Pass criteria missing","You need to check (or have a good indication) of all the criteria above (i.e. all the checkboxes need to be checked)")
@@ -75,10 +88,36 @@ class Vote(QMainWindow):
     @pyqtSlot()
     def failVote(self):
         if self.passUnlocked:
-            self.thumb(False)
+            if QMessageBox.Ok == QMessageBox.question(self, "Are you sure ?", "Remember, the reasons for failing an app should be based on severe issues. It's more of a 'does it work' rather than a 'how well does it work'. If in doubt, please consult the QA a documentation."):
+                self.comment()
+                self.thumb(False)
         else:
             QMessageBox.information(self, "Fail criteria missing","You need to supply a reason for failing this package. Remember, it's not about whether you like the application, how pretty or cool it is - it is about whether it negatively impacts your usage of your device and if it is well-behaved (isn't illegal, is possible to report errors, etc). The slickness/coolness of the app will be judged by awarding it with 1-5 stars in Extras, not here.")
       
+    @pyqtSlot()
+    def comment(self):
+        try: 
+            self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, True)
+            QApplication.processEvents()
+        except: pass
+        commentdata = { "content" : self.id, "message" : self.ui.textEdit.toPlainText(), "type" : 1 }
+        print commentdata
+        self.ui.textEdit().setText("")
+        passw_mgr = urllib2.HTTPPasswordMgrWithDefaultRealm()
+        passw_mgr.add_password( None,
+                          'https://maemo.org/packages/api/v1/comments/add/',
+                          str(self.settings.data.value("username").toString()).lower(),
+                          str(self.settings.data.value("password").toString()))
+        auth_handler = urllib2.HTTPBasicAuthHandler(passw_mgr)
+        self.opener = urllib2.build_opener(auth_handler)
+        
+        r = self.opener.open("https://maemo.org/packages/api/v1/comments/add/", urllib.urlencode(commentdata))
+        ret = r.read()
+        try: 
+            self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, False)
+            QApplication.processEvents()
+        except: pass
+        
     def thumb(self, b):
         if b:
             message = 1
@@ -96,6 +135,10 @@ class Vote(QMainWindow):
 
         try:
             if os.path.exists("/home/user/.kisstester_rw"):
+                try: 
+                    self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, True)
+                    QApplication.processEvents()
+                except: pass
                 r = self.opener.open("https://maemo.org/packages/api/v1/favs/add/", urllib.urlencode(votedata))
                 ret = r.read()
                 # voting is slow, maybe we need a progress bar here, too...
@@ -103,6 +146,10 @@ class Vote(QMainWindow):
                     QMessageBox.information(self, "Pass :)","Package thumbed up. It might take a few minutes until your vote appears in the listing.")
                 else:
                     QMessageBox.information(self, "Fail :(","Package thumbed down. It might take a few minutes until your vote appears in the listing.")
+                try: 
+                    self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, False)
+                    QApplication.processEvents()
+                except: pass
                 self.close()
             else:
                 QMessageBox.warning(self, "WARNING", "KISStester operating in read-only mode. Please check the testing-squad mailing-list before you do something you don't want to :)")
